==> qt-creator-opensource-src-3.2.2.zip: qt-creator-opensource-src-3.2.2/src/plugins/qnx/bardescriptoreditorentrypointwidget.h <==
/**************************************************************************
**
** Copyright (C) 2014 BlackBerry Limited. All rights reserved.
**
** Contact: BlackBerry (qt@blackberry.com)
** Contact: KDAB (info@kdab.com)
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QNX_INTERNAL_BARDESCRIPTOREDITORENTRYPOINTWIDGET_H
#define QNX_INTERNAL_BARDESCRIPTOREDITORENTRYPOINTWIDGET_H

#include "bardescriptoreditorabstractpanelwidget.h"

#include <QStandardItemModel>

QT_BEGIN_NAMESPACE
class QItemSelection;
class QLabel;
class QStringListModel;
QT_END_NAMESPACE

namespace Qnx {
namespace Internal {

namespace Ui { class BarDescriptorEditorEntryPointWidget; }

class BarDescriptorEditorEntryPointWidget : public BarDescriptorEditorAbstractPanelWidget
{
    Q_OBJECT

public:
    explicit BarDescriptorEditorEntryPointWidget(QWidget *parent = 0);
    ~BarDescriptorEditorEntryPointWidget();

    void setAssetsModel(QStandardItemModel *assetsModel);

signals:
    void imageAdded(const QString &path);
    void imageRemoved(const QString &path);

protected:
    void updateWidgetValue(BarDescriptorDocument::Tag tag, const QVariant &value);
    void emitChanged(BarDescriptorDocument::Tag tag);

private slots:
    void setApplicationIconDelayed(const QString &iconPath);
    void setApplicationIconPreview(const QString &path);
    void validateIconSize(const QString &path);
    void handleIconChanged(const QString &path);
    void clearIcon();

    void browseForSplashScreen();
    void removeSelectedSplashScreen();
    void handleSplashScreenSelectionChanged(const QItemSelection &selected, const QItemSelection &deselected);
    void appendSplashScreenDelayed(const QString &splashScreenPath);

private:
    enum ImageValidationResult {
        Valid,
        CouldNotLoad,
        IncorrectSize
    };

    void setImagePreview(QLabel *previewLabel, const QString &path);
    void validateSplashScreenSize(const QString &path);
    void validateImage(const QString &path, QLabel *warningMessage, QLabel *warningPixmap, const QSize &maximumSize);

    QString localAssetPathFromDestination(const QString &path);

    QStringListModel *m_splashScreenModel;
    QWeakPointer<QStandardItemModel> m_assetsModel;

    QString m_prevIconPath;

    Ui::BarDescriptorEditorEntryPointWidget *m_ui;
};


} // namespace Internal
} // namespace Qnx
#endif // QNX_INTERNAL_BARDESCRIPTOREDITORENTRYPOINTWIDGET_H

==> qt-creator-opensource-src-3.3.0.zip: qt-creator-opensource-src-3.3.0/src/plugins/qnx/bardescriptoreditorentrypointwidget.h <==
/**************************************************************************
**
** Copyright (C) 2014 BlackBerry Limited. All rights reserved.
**
** Contact: BlackBerry (qt@blackberry.com)
** Contact: KDAB (info@kdab.com)
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QNX_INTERNAL_BARDESCRIPTOREDITORENTRYPOINTWIDGET_H
#define QNX_INTERNAL_BARDESCRIPTOREDITORENTRYPOINTWIDGET_H

#include "bardescriptoreditorabstractpanelwidget.h"

#include <QPointer>
#include <QStandardItemModel>

QT_BEGIN_NAMESPACE
class QItemSelection;
class QLabel;
class QStringListModel;
QT_END_NAMESPACE

namespace Qnx {
namespace Internal {

namespace Ui { class BarDescriptorEditorEntryPointWidget; }

class BarDescriptorEditorEntryPointWidget : public BarDescriptorEditorAbstractPanelWidget
{
    Q_OBJECT

public:
    explicit BarDescriptorEditorEntryPointWidget(QWidget *parent = 0);
    ~BarDescriptorEditorEntryPointWidget();

    void setAssetsModel(QStandardItemModel *assetsModel);

signals:
    void imageAdded(const QString &path);
    void imageRemoved(const QString &path);

protected:
    void updateWidgetValue(BarDescriptorDocument::Tag tag, const QVariant &value);
    void emitChanged(BarDescriptorDocument::Tag tag);

private slots:
    void setApplicationIconDelayed(const QString &iconPath);
    void setApplicationIconPreview(const QString &path);
    void validateIconSize(const QString &path);
    void handleIconChanged(const QString &path);
    void clearIcon();

    void browseForSplashScreen();
    void removeSelectedSplashScreen();
    void handleSplashScreenSelectionChanged(const QItemSelection &selected, const QItemSelection &deselected);
    void appendSplashScreenDelayed(const QString &splashScreenPath);

private:
    enum ImageValidationResult {
        Valid,
        CouldNotLoad,
        IncorrectSize
    };

    void setImagePreview(QLabel *previewLabel, const QString &path);
    void validateSplashScreenSize(const QString &path);
    void validateImage(const QString &path, QLabel *warningMessage, QLabel *warningPixmap, const QSize &maximumSize);

    QString localAssetPathFromDestination(const QString &path);

    QStringListModel *m_splashScreenModel;
    QPointer<QStandardItemModel> m_assetsModel;

    QString m_prevIconPath;

    Ui::BarDescriptorEditorEntryPointWidget *m_ui;
};


} // namespace Internal
} // namespace Qnx
#endif // QNX_INTERNAL_BARDESCRIPTOREDITORENTRYPOINTWIDGET_H
